@@ -6,16 +6,16 @@ from __future__ import annotations
 
 import os
 import sys
-from collections.abc import ItemsView, Sequence
+import warnings
+from collections.abc import Sequence
 from dataclasses import dataclass
-from typing import TYPE_CHECKING
-
+from typing import TYPE_CHECKING, Literal
 if TYPE_CHECKING:
     from types import FrameType
     from typing import Any, Callable, ItemsView, Sized
 
 #: The release version
-version = "2.0.18"
+version = '2.1.12'
 __version__ = version
 
 MIN_PYTHON_VERSION = 3, 8
@@ -30,20 +30,17 @@ compat_platform = sys.platform
 if "bsd" in compat_platform:
     compat_platform = "linux-compat"
 
-_enable_optimisations = not __debug__
-if getattr(sys, "frozen", None):
-    _enable_optimisations = True
+if compat_platform == "cygwin":
+    # This hack pretends that the posix-like ctypes provides windows
+    # functionality.  COM does not work with this hack, so there is no
+    # DirectSound support.
+    import ctypes
 
+    ctypes.windll = ctypes.cdll
+    ctypes.oledll = ctypes.cdll
+    ctypes.WINFUNCTYPE = ctypes.CFUNCTYPE
+    ctypes.HRESULT = ctypes.c_long
 
-_SPECIAL_OPTION_VALIDATORS = {
-    "audio": lambda x: isinstance(x, Sequence),
-    "vsync": lambda x: x is None or isinstance(x, bool),
-}
-
-_OPTION_TYPE_VALIDATORS = {
-    "bool": lambda x: isinstance(x, bool),
-    "int": lambda x: isinstance(x, int),
-}
 
 @dataclass
 class Options:
@@ -109,8 +106,12 @@ class Options:
     debug_trace_depth: int = 1
     debug_trace_flush: bool = True
 
+    debug_com: bool = False
+    """If ``True``, prints information on COM calls. This can potentially help narrow down issues with certain libraries
+    that utilize COM calls. Only applies to the Windows platform."""
+
     debug_win32: bool = False
-    """If ``True``, prints error messages related to Windows library calls. Usually get's information from
+    """If ``True``, prints error messages related to Windows library calls. Usually gets information from
     ``Kernel32.GetLastError``. This information is output to a file called ``debug_win32.log``."""
 
     debug_input: bool = False
@@ -133,23 +134,26 @@ class Options:
      must be loaded after the window using them was created).  Recommended
      for advanced developers only.
 
-     .. versionadded:: 1.1"""
+     .. versionadded:: 1.1
+     """
 
     vsync: bool | None = None
     """If set, the `pyglet.window.Window.vsync` property is ignored, and
      this option overrides it (to either force vsync on or off).  If unset,
      or set to None, the `pyglet.window.Window.vsync` property behaves
-     as documented."""
+     as documented.
+     """
 
     xsync: bool = True
-    """If set (the default), pyglet will attempt to synchronise the drawing of
-     double-buffered windows to the border updates of the X11 window
-     manager.  This improves the appearance of the window during resize
-     operations.  This option only affects double-buffered windows on
-     X11 servers supporting the Xsync extension with a window manager
-     that implements the _NET_WM_SYNC_REQUEST protocol.
+    """If ``True`` (the default), pyglet will attempt to synchronise the
+    drawing of double-buffered windows to the border updates of the X11
+    window manager. This improves the appearance of the window during
+    resize operations.  This option only affects double-buffered windows on
+    X11 servers supporting the Xsync extension with a window manager that
+    implements the _NET_WM_SYNC_REQUEST protocol.
 
-     .. versionadded:: 1.1"""
+     .. versionadded:: 1.1
+     """
 
     xlib_fullscreen_override_redirect: bool = False
     """If ``True``, pass the xlib.CWOverrideRedirect flag when creating a fullscreen window.
@@ -171,6 +175,11 @@ class Options:
     .. versionadded:: 2.0
     """
 
+    text_antialiasing: bool = True
+    """If ``True``, font renderers will improve text quality by adding antialiasing to the rendered characters. If
+    ``False``, text quality will appear pixelated.
+    """
+
     headless: bool = False
     """If ``True``, visible Windows are not created and a running desktop environment is not required. This option
     is useful when running pyglet on a headless server, or compute cluster. OpenGL drivers with ``EGL`` support are
@@ -182,14 +191,17 @@ class Options:
     GPU to use. This is only useful on multi-GPU systems.
     """
 
-    win32_disable_shaping: bool = False
-    """If ``True``, will disable the shaping process for the default Windows font renderer to offer a performance
-    speed up. If your font is simple, monospaced, or you require no advanced OpenType features, this option may be
-    useful. You can try enabling this to see if there is any impact on clarity for your font. The advance will be
-    determined by the glyph width.
+    text_shaping: Literal["platform", "harfbuzz", False] = 'platform'
+    """Determines how text is processed and displayed based on features of the font.
 
-    .. note:: Shaping is the process of determining which character glyphs to use and specific placements of those
-       glyphs when given a full string of characters.
+    Valid option names are:
+
+     * ``False``, Disables the shaping process for text. This may increase performance as it reduces the amount
+        of calls during rendering. If your font is simple, monospaced, or you require no advanced OpenType features,
+        this option may be useful.
+     * ``'platform'``, Uses platform's font system for shaping. Supported by Windows (DirectWrite) and Mac (CoreText).
+     * ``'harfbuzz'``, Utilize the harfbuzz library for font shaping. This requires an optional dependency, if not
+     found, it will fallback to platform shaping.
 
     .. versionadded:: 2.0
     """
@@ -220,7 +232,8 @@ class Options:
     be useful for debugging or special uses cases. A controller can only be controlled by either ``XInput`` or
     ``DirectInput``, not both.
 
-    .. versionadded:: 2.0"""
+    .. versionadded:: 2.0
+    """
 
     com_mta: bool = False
     """If ``True``, this will enforce COM Multithreaded Apartment Mode for Windows applications. By default, pyglet
@@ -242,6 +255,38 @@ class Options:
 
     .. versionadded:: 2.0.5"""
 
+    dpi_scaling: Literal["real", "scaled", "stretch", "platform"] = "platform"
+    """For 'HiDPI' displays, Window behavior can differ between operating systems. Defaults to `'platform'`.
+
+    The current options are an attempt to create consistent behavior across all of the operating systems.
+
+    `'real'` (default): Provides a 1:1 pixel for Window frame size and framebuffer. Primarily used for game applications
+    to ensure you are getting the exact pixels for the resolution. If you provide an 800x600 window, you can ensure it
+    will be 800x600 pixels when the user chooses it.
+
+    `'scaled'`: Window size is scaled based on the DPI ratio. Window size and content (projection) size matches the full
+    framebuffer. Primarily used for any applications that wish to become DPI aware. You must rescale and reposition your
+    content to take advantage of the larger framebuffer. An 800x600 with a 150% DPI scaling would be changed to
+    1200x900 for both `window.get_size` and `window.get_framebuffer_size()`.
+
+    Keep in mind that pyglet objects may not be scaled proportionately, so this is left up to the developer.
+    The :py:attr:`~pyglet.window.Window.scale` & :py:attr:`~pyglet.window.Window.dpi` attributes can be queried as a
+    reference when determining object creation.
+
+    `'stretch'`:  Window is scaled based on the DPI ratio. However, content size matches original requested size of the
+    window, and is stretched to fit the full framebuffer. This mimics behavior of having no DPI scaling at all. No
+    rescaling and repositioning of content will be necessary, but at the cost of blurry content depending on the extent
+    of the stretch. For example, 800x600 at 150% DPI will be 800x600 for `window.get_size()` and 1200x900 for
+    `window.get_framebuffer_size()`.
+
+    `'platform'`: A DPI aware window is created, however window sizing and framebuffer sizing is not interfered with
+    by Pyglet. Final sizes are dictated by the platform the window was created on. It is up to the user to make any
+    platform adjustments themselves such as sizing on a platform, mouse coordinate adjustments, or framebuffer size
+    handling. On Windows and X11, the framebuffer and the requested window size will always match in pixels 1:1. On
+    MacOS, depending on a Hi-DPI display, you may get a different sized framebuffer than the window size. This option
+    does allow `window.dpi` and `window.scale` to return their respective values.
+    """
+
     shader_bind_management: bool = True
     """If ``True``, this will enable internal management of Uniform Block bindings for
      :py:class:`~pyglet.graphics.shader.ShaderProgram`'s.
@@ -249,7 +294,8 @@ class Options:
     If ``False``, bindings will not be managed by Pyglet. The user will be responsible for either setting the binding
     points through GLSL layouts (4.2 required) or manually through ``UniformBlock.set_binding``.
 
-    .. versionadded:: 2.0.16"""
+    .. versionadded:: 2.0.16
+    """
 
     def get(self, item: str, default: Any = None) -> Any:
         return self.__dict__.get(item, default)
@@ -261,42 +307,31 @@ class Options:
         return self.__dict__[item]
 
     def __setitem__(self, key: str, value: Any) -> None:
-        assert key in self.__annotations__, f"Invalid option name: '{key}'"
-        assert (_SPECIAL_OPTION_VALIDATORS.get(key, None) or _OPTION_TYPE_VALIDATORS[self.__annotations__[key]])(value), \
-            f"Invalid type: '{type(value)}' for '{key}'"
         self.__dict__[key] = value
 
 
 #: Instance of :py:class:`~pyglet.Options` used to set runtime options.
 options: Options = Options()
 
-_OPTION_TYPE_REMAPS = {
-    "audio": "sequence",
-    "vsync": "bool",
-}
 
-for _key, _type in options.__annotations__.items():
+for _option_name, _type_str in options.__annotations__.items():
     """Check Environment Variables for pyglet options"""
-    if _value := os.environ.get(f"PYGLET_{_key.upper()}"):
-        _type = _OPTION_TYPE_REMAPS.get(_key, _type)
-        if _type == 'sequence':
-            options[_key] = _value.split(",")
-        elif _type == 'bool':
-            options[_key] = _value in ("true", "TRUE", "True", "1")
-        elif _type == 'int':
-            options[_key] = int(_value)
+    if _value := os.environ.get(f"PYGLET_{_option_name.upper()}"):
+        if 'Sequence' in _type_str:
+            setattr(options, _option_name, _value.split(","))
+        elif 'bool' in _type_str:
+            setattr(options, _option_name, _value in ("true", "TRUE", "True", "1"))
+        elif 'int' in _type_str:
+            setattr(options, _option_name, int(_value))
+        elif 'Literal' in _type_str and _value in _type_str:
+            setattr(options, _option_name, _value)
+        else:
+            warnings.warn(f"Invalid value '{_value}' for {_option_name}. Expecting {_type_str}")
 
 
-if compat_platform == "cygwin":
-    # This hack pretends that the posix-like ctypes provides windows
-    # functionality.  COM does not work with this hack, so there is no
-    # DirectSound support.
-    import ctypes
+if (__debug__ is False) or getattr(sys, "frozen", False):
+    options.debug_gl = False
 
-    ctypes.windll = ctypes.cdll
-    ctypes.oledll = ctypes.cdll
-    ctypes.WINFUNCTYPE = ctypes.CFUNCTYPE
-    ctypes.HRESULT = ctypes.c_long
 
 # Call tracing
 # ------------
@@ -432,9 +467,9 @@ class _ModuleProxy:
 if TYPE_CHECKING:
     from . import (
         app,
-        canvas,
         clock,
         customtypes,
+        display,
         event,
         font,
         gl,
@@ -454,16 +489,16 @@ if TYPE_CHECKING:
     )
 else:
     app = _ModuleProxy("app")  # type: ignore
-    canvas = _ModuleProxy("canvas")  # type: ignore
     clock = _ModuleProxy("clock")  # type: ignore
     customtypes = _ModuleProxy("customtypes")  # type: ignore
+    display = _ModuleProxy("display")  # type: ignore
     event = _ModuleProxy("event")  # type: ignore
     font = _ModuleProxy("font")  # type: ignore
     gl = _ModuleProxy("gl")  # type: ignore
     graphics = _ModuleProxy("graphics")  # type: ignore
     gui = _ModuleProxy("gui")  # type: ignore
     image = _ModuleProxy("image")  # type: ignore
-    input = _ModuleProxy("input") # noqa: A001 TODO: change this name  # type: ignore
+    input = _ModuleProxy("input")  # type: ignore
     lib = _ModuleProxy("lib")  # type: ignore
     math = _ModuleProxy("math")  # type: ignore
     media = _ModuleProxy("media")  # type: ignore
@@ -475,5 +510,5 @@ else:
     window = _ModuleProxy("window")  # type: ignore
 
 # Call after creating proxies:
-if options["debug_trace"]:
+if options.debug_trace is True:
     _install_trace()
