@@ -82,12 +82,13 @@ if TYPE_CHECKING:
 vertex_source = """#version 150 core
     in vec2 position;
     in vec2 translation;
-    in vec4 color;
+    in vec4 colors;
     in float zposition;
+
     in float rotation;
 
 
-    out vec4 vertex_color;
+    out vec4 vertex_colors;
 
     uniform WindowBlock
     {
@@ -108,17 +109,17 @@ vertex_source = """#version 150 core
         m_rotation[1][1] =  cos(-radians(rotation));
 
         gl_Position = window.projection * window.view * m_translate * m_rotation * vec4(position, zposition, 1.0);
-        vertex_color = color;
+        vertex_colors = colors;
     }
 """
 
 fragment_source = """#version 150 core
-    in vec4 vertex_color;
+    in vec4 vertex_colors;
     out vec4 final_color;
 
     void main()
     {
-        final_color = vertex_color;
+        final_color = vertex_colors;
         // No GL_ALPHA_TEST in core, use shader to discard.
         if(final_color.a < 0.01){
             discard;
@@ -228,7 +229,7 @@ def _get_segment(p0: tuple[float, float] | list[float], p1: tuple[float, float]
     scale2 = min(scale2, 2.0 * thickness)
 
     # Make these tuples instead of Vec2 because accessing
-    # members of Vec2 is suprisingly slow
+    # members of Vec2 is surprisingly slow
     miter1_scaled_p = (v_miter1.x * scale1, v_miter1.y * scale1)
     miter2_scaled_p = (v_miter2.x * scale2, v_miter2.y * scale2)
 
@@ -376,12 +377,12 @@ class ShapeBase(ABC):
     def _update_color(self) -> None:
         """Send the new colors for each vertex to the GPU.
 
-        This method must set the contents of `self._vertex_list.color`
+        This method must set the contents of `self._vertex_list.colors`
         using a list or tuple that contains the RGBA color components
         for each vertex in the shape. This is usually done by repeating
         `self._rgba` for each vertex.
         """
-        self._vertex_list.color[:] = self._rgba * self._num_verts
+        self._vertex_list.colors[:] = self._rgba * self._num_verts
 
     def _update_translation(self) -> None:
         self._vertex_list.translation[:] = (self._x, self._y) * self._num_verts
@@ -814,7 +815,7 @@ class Arc(ShapeBase):
                 The angle of the arc, in degrees. Defaults to 360.0, which is
                 a full circle.
             start_angle:
-                The start angle of the arc, in radians. Defaults to 0.
+                The start angle of the arc, in degrees. Defaults to 0.
             closed:
                 If ``True``, the ends of the arc will be connected with a line.
                 defaults to ``False``.
@@ -862,8 +863,9 @@ class Arc(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1032,8 +1034,9 @@ class BezierCurve(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1169,8 +1172,9 @@ class Circle(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._segments * 3, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1287,8 +1291,9 @@ class Ellipse(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._segments * 3, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1420,8 +1425,9 @@ class Sector(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1562,8 +1568,9 @@ class Line(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             6, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1688,8 +1695,9 @@ class Rectangle(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             6, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -1831,11 +1839,12 @@ class BorderedRectangle(ShapeBase):
         self._vertex_list = self._program.vertex_list_indexed(
             8, self._draw_mode, indices, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * 4 + self._border_rgba * 4),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * 4 + self._border_rgba * 4),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _update_color(self) -> None:
-        self._vertex_list.color[:] = self._rgba * 4 + self._border_rgba * 4
+        self._vertex_list.colors[:] = self._rgba * 4 + self._border_rgba * 4
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2045,11 +2054,12 @@ class Box(ShapeBase):
         self._vertex_list = self._program.vertex_list_indexed(
             self._num_verts, self._draw_mode, indices, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _update_color(self):
-        self._vertex_list.color[:] = self._rgba * self._num_verts
+        self._vertex_list.colors[:] = self._rgba * self._num_verts
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2224,8 +2234,9 @@ class RoundedRectangle(pyglet.shapes.ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2375,8 +2386,9 @@ class Triangle(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             3, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2511,9 +2523,9 @@ class Star(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            rotation=('f', (self._rotation,) * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2636,8 +2648,9 @@ class Polygon(ShapeBase):
             earcut.earcut(vertices),
             self._batch, self._group,
             position=('f', vertices),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
@@ -2721,8 +2734,9 @@ class MultiLine(ShapeBase):
         self._vertex_list = self._program.vertex_list(
             self._num_verts, self._draw_mode, self._batch, self._group,
             position=('f', self._get_vertices()),
-            color=('Bn', self._rgba * self._num_verts),
-            translation=('f', (self._x, self._y) * self._num_verts))
+            colors=('Bn', self._rgba * self._num_verts),
+            translation=('f', (self._x, self._y) * self._num_verts),
+            rotation=('f', (self._rotation,) * self._num_verts))
 
     def _get_vertices(self) -> Sequence[float]:
         if not self._visible:
